import_bis_debt_sec: This function imports debt securities from BIS format

import_bis_debt_secR Documentation

This function imports debt securities from BIS format

Description

This function imports debt securities from BIS format

Usage

import_bis_debt_sec(
  file_path,
  my_frequency = NULL,
  my_measure = NULL,
  my_issuer_residence = NULL,
  my_issuer_nationality = NULL,
  my_issuer_sector_immediate_borrower = NULL,
  my_issuer_sector_ultimate_borrower = NULL,
  my_issue_market = NULL,
  my_issue_type = NULL,
  my_issue_currency_group = NULL,
  my_issue_currency = NULL,
  my_original_maturity = NULL,
  my_remaining_maturity = NULL,
  my_rate_type = NULL,
  my_default_risk = NULL,
  my_collateral_type = NULL,
  pivot_to_long = FALSE
)

Arguments

file_path

string a file path to the source data file

my_frequency

time frequency of the data (default is NULL), available options are:

  • Quarterly

my_measure

(default is NULL), available options are:

  • Amounts outstanding

  • Net issues

  • Gross issues

my_issuer_residence

(default is NULL) The residence of the issuer is the country where the issuer is incorporated.

my_issuer_nationality

(default is NULL) The nationality of the issuer is the country where the issuer's parent is headquartered

my_issuer_sector_immediate_borrower

(default is NULL), available options are:

  • All issuers

  • Financial corporations

  • Private banks

  • International institutions

  • Public banks

  • General government

  • Non-financial corporations

  • Private other financial institutions

  • Central bank

  • Public other financial institutions

my_issuer_sector_ultimate_borrower

(default is NULL), available options are:

  • All issuers

  • Financial corporations

  • Private banks

  • International institutions

  • Public banks

  • General government

  • Non-financial corporations

  • Private other financial institutions

  • Central bank

  • Public other financial institutions

my_issue_market

(default is NULL), available options are:

  • All markets

  • Domestic market

  • International markets

my_issue_type

(default is NULL), available options are:

  • All issue types

my_issue_currency_group

(default is NULL), available options are:

  • All currencies

  • Foreign currencies

  • Domestic currency

my_issue_currency

(default is NULL), There are 65 available options, the special are:

  • Total all currencies

  • Sum of ECU, Euro and legacy currencies now included in the Euro

pivot_to_long

reshape the data to long format? Default is FALSE


MichaelGurkov/MiscImport documentation built on June 6, 2023, 10:53 p.m.