import_bis_total_credit: This function imports total credit to private sector from BIS...

import_bis_total_creditR Documentation

This function imports total credit to private sector from BIS format

Description

This function imports total credit to private sector from BIS format

Usage

import_bis_total_credit(
  file_path = NULL,
  my_frequency = NULL,
  my_borrowing_sector = NULL,
  my_lending_sector = NULL,
  my_valuation_method = NULL,
  my_unit_type = NULL,
  my_adjustment = NULL,
  pivot_to_long = FALSE
)

Arguments

file_path

string a file path to the source data file

my_frequency

time frequency of the data (default is NULL), available options are:

  • Quarterly

my_borrowing_sector

(default is NULL), available options are:

  • Non financial sector

  • General government

  • Households & NPISHs

  • Non-financial corporations

  • Private non-financial sector

my_lending_sector

(default is NULL), available options are:

  • All sectors

  • Banks, domestic

my_valuation_method

(default is NULL), toggles the difference between credit and debt. available options are:

  • Nominal value

  • Market value

my_unit_type

(default is NULL), available options are:

  • US Dollar

  • Percentage of GDP

  • Percentage of GDP-PPP

  • Domestic currency

my_adjustment

(default is NULL), available options are:

  • Adjusted for breaks

  • Unadjusted for breaks

pivot_to_long

reshape the data to long format? Default is FALSE


MichaelGurkov/MiscImport documentation built on June 6, 2023, 10:53 p.m.