| import_bis_debt_sec | R Documentation |
This function imports debt securities from BIS format
import_bis_debt_sec(
file_path,
my_frequency = NULL,
my_measure = NULL,
my_issuer_residence = NULL,
my_issuer_nationality = NULL,
my_issuer_sector_immediate_borrower = NULL,
my_issuer_sector_ultimate_borrower = NULL,
my_issue_market = NULL,
my_issue_type = NULL,
my_issue_currency_group = NULL,
my_issue_currency = NULL,
my_original_maturity = NULL,
my_remaining_maturity = NULL,
my_rate_type = NULL,
my_default_risk = NULL,
my_collateral_type = NULL,
pivot_to_long = FALSE
)
file_path |
string a file path to the source data file |
my_frequency |
time frequency of the data (default is NULL), available options are:
|
my_measure |
(default is NULL), available options are:
|
my_issuer_residence |
(default is NULL) The residence of the issuer is the country where the issuer is incorporated. |
my_issuer_nationality |
(default is NULL) The nationality of the issuer is the country where the issuer's parent is headquartered |
my_issuer_sector_immediate_borrower |
(default is NULL), available options are:
|
my_issuer_sector_ultimate_borrower |
(default is NULL), available options are:
|
my_issue_market |
(default is NULL), available options are:
|
my_issue_type |
(default is NULL), available options are:
|
my_issue_currency_group |
(default is NULL), available options are:
|
my_issue_currency |
(default is NULL), There are 65 available options, the special are:
|
pivot_to_long |
reshape the data to long format? Default is FALSE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.