| import_bis_total_credit | R Documentation |
This function imports total credit to private sector from BIS format
import_bis_total_credit(
file_path = NULL,
my_frequency = NULL,
my_borrowing_sector = NULL,
my_lending_sector = NULL,
my_valuation_method = NULL,
my_unit_type = NULL,
my_adjustment = NULL,
pivot_to_long = FALSE
)
file_path |
string a file path to the source data file |
my_frequency |
time frequency of the data (default is NULL), available options are:
|
my_borrowing_sector |
(default is NULL), available options are:
|
my_lending_sector |
(default is NULL), available options are:
|
my_valuation_method |
(default is NULL), toggles the difference between credit and debt. available options are:
|
my_unit_type |
(default is NULL), available options are:
|
my_adjustment |
(default is NULL), available options are:
|
pivot_to_long |
reshape the data to long format? Default is FALSE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.